Crate endpoint_gen
endpoint_
gen
1.5.1
All Items
Crate Items
Modules
Derive Macros
Crate
endpoint_
gen
Modules

definitions
docs
rust
service
Derive Macros

Definition
Variant
Derive macro ensures that the type manually implements GenElement
. This enforces that any type used as a Definition variant has proper validation logic.