pub enum Definition {
EndpointSchema(EndpointSchemaDefinition),
EndpointSchemaList(EndpointSchemaListDefinition),
Enum(EnumElement),
EnumList(EnumListDefinition),
Struct(StructElement),
StructList(StructListDefinition),
}Expand description
Marker trait for types that can be used as Definition variants All types used in Definition must implement this to ensure they are properly validatable
Variants
EndpointSchema(EndpointSchemaDefinition)
EndpointSchemaList(EndpointSchemaListDefinition)
Enum(EnumElement)
EnumList(EnumListDefinition)
Struct(StructElement)
StructList(StructListDefinition)
Implementations
Sourceimpl Definition
impl Definition
pub fn validate_self(&self) -> Result<()>